summaryrefslogtreecommitdiff
path: root/riscos/url_complete.c
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/url_complete.c')
-rw-r--r--riscos/url_complete.c15
1 files changed, 10 insertions, 5 deletions
diff --git a/riscos/url_complete.c b/riscos/url_complete.c
index 4d5f9d213..b804f741a 100644
--- a/riscos/url_complete.c
+++ b/riscos/url_complete.c
@@ -709,17 +709,22 @@ bool ro_gui_url_complete_click(wimp_pointer *pointer)
/** \todo The interaction of components here is hideous */
/* Do NOT make any attempt to use any of the global url
* completion variables after this call to browser_window_go.
* They will be invalidated by (at least):
* + gui_window_set_url
* + destruction of (i)frames within the current page
* Any attempt to use them will probably result in a crash.
*/
- browser_window_go(g->bw,
- nsurl_access(url_complete_matches[
- url_complete_matches_selection]),
- 0, true);
+ browser_window_navigate(g->bw,
+ url_complete_matches[url_complete_matches_selection],
+ NULL,
+ BROWSER_WINDOW_GO_FLAG_HISTORY |
+ BROWSER_WINDOW_GO_FLAG_VERIFIABLE,
+ NULL,
+ NULL,
+ NULL);
+
ro_gui_url_complete_close();
/* Adjust just sets the text */
@@ -709,17 +709,22 @@ bool ro_gui_url_complete_click(wimp_pointer *pointer)
/** \todo The interaction of components here is hideous */
/* Do NOT make any attempt to use any of the global url
- * completion variables after this call to browser_window_go.
+ * completion variables after this call to browser_window_navigate.
* They will be invalidated by (at least):
* + gui_window_set_url